==> tine20-allinone_2019.12.5.tar.bz2: Admin/js/Admin-lang-es_MX-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Admin **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:09+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Spanish (Mexico) (http://www.transifex.com/tine20/tine20/language/es_MX/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: es_MX\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "User, Users"
: [
  "Usuario"
 ,"Usuarios"

]
, "Groups"
: "Grupos"

, "Roles"
: "Cargos"

, "Applications"
: "Aplicaciones"

, "Containers"
: "Contenedores"

, "Shared Tags"
: "Etiquetas Compartidas"

, "Customfields"
: "Campos Personalizados"

, "Computers"
: "Computadoras"

, "Access Log, Access Logs"
: [
  "Log de Acceso"
 ,"Logs de Acceso"

]
, "Server Information"
: ""

, "ActiveSync Devices"
: ""

, "Admin"
: "Admin"

, "Refresh"
: ""

, "Name"
: "Nombre"

, "Size"
: ""

, "Revision Size"
: ""

, "Total size of all available revisions"
: ""

, "Quota Usage"
: ""

, "Computer, Computers"
: [
  "Computadora"
 ,"Computadoras"

]
, "Default Addressbook for new contacts and groups"
: "Agenda predeterminada para nuevos contactos y grupos"

, "Group, Groups"
: [
  "Grupo"
 ,"Grupos"

]
, "Application, Applications"
: [
  "Aplicación"
 ,"Aplicaciones"

]
, "Config, Configs"
: [
  ""
 ,""

]
, "Configs"
: ""

, "Please wait"
: "Por favor espere"

, "Updating Memberships"
: "Actualizando Membresias"

, "Failed"
: "Falló"

, "Could not save group."
: "No se pudo guardar el grupo."

, "Errors"
: "Errores"

, "Please fix the errors noted."
: "Por favor corrija los errores indicados."

, "Group Name"
: "Nombre del Grupo"

, "Description"
: "Descripción"

, "Visibility"
: "Visibilidad"

, "Display in addressbook"
: "Mostrar en libreta de direcciones"

, "Hide from addressbook"
: "Esconder de la libreta de direcciones"

, "Saved in Addressbook"
: "Guardado en libreta de direcciones"

, "Group Members"
: "Miembros del Grupo"

, "Transferring {0}..."
: "Transfiriendo {0}..."

, "Add new group"
: "Agregar Nuevo Grupo"

, "Edit Group \"{0}\""
: "Editar Grupo \"{0}\""

, "Enable Application"
: ""

, "Disable Application"
: ""

, "Settings"
: ""

, "{0} Settings"
: "{0} Configuraciones"

, "enable application"
: "habilitar aplicación"

, "disable application"
: "deshabilitar aplicación"

, "settings"
: "configuraciones"

, "Search:"
: "Buscar:"

, "disabled"
: "deshabilitado"

, "enabled"
: "habilitado"

, "unknown status ({0})"
: "Estado desconocido ({0})"

, "Displaying application {0} - {1} of {2}"
: "Mostrando aplicación {0} - {1} of {2}"

, "No applications to display"
: "No hay aplicaciones para mostrar"

, "Order"
: "Ordenar"

, "Status"
: "Estado"

, "Version"
: "Versión"

, "Confirm"
: "Confirmar"

, "Do you really want to delete the selected groups?"
: "¿Realmente desea borrar los grupos seleccionados?"

, "Deleting group(s)..."
: "Borrando grupo(s)..."

, "Some error occurred while trying to delete the group."
: "Ocurrió un error al intentar borrar este grupo."

, "Add Group"
: ""

, "Edit Group"
: ""

, "Delete Group"
: ""

, "Displaying groups {0} - {1} of {2}"
: "Mostrando grupos {0} - {1} of {2}"

, "No groups to display"
: "No hay grupos para mostrar"

, "ID"
: "ID"

, "Creation Time"
: ""

, "Created By"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Computer Name"
: "Nombre del Computador"

, "IP Address"
: "Dirección IP"

, "Login Time"
: "Hora de Ingreso"

, "Logout Time"
: "Hora de Salida"

, "Client Type"
: "Tipo de Cliente"

, "Session ID"
: "ID de Sesión"

, "Login Name"
: "Nombre de Usuario"

, "Result"
: "Resultado"

, "user blocked"
: "usuario bloqueado"

, "password expired"
: "contraseña caducada"

, "user disabled"
: "usuario deshabilitado"

, "invalid password"
: "contraseña incorrecta"

, "ambiguous username"
: "nombre de usuario ambiguo"

, "user not found"
: "usuario no encontrado"

, "failure"
: "falla"

, "success"
: "exitoso"

, "Could not save role."
: "No se pudo guardar cargo."

, "Deleting role..."
: "Borrando cargo..."

, "Some error occurred while trying to delete the role."
: "Ocurrió un error al intentar borrar el cargo."

, "Rights"
: "Derechos"

, "Members"
: "Miembros"

, "Role Name"
: "Nombre del Cargo"

, "Role"
: "Cargo"

, "Add New Role"
: "Agregar Nuevo Cargo"

, "Edit Role \"{0}\""
: "Editar Cargo \"{0}\""

, "Container Name"
: "Nombre del Contenedor"

, "Type"
: "Tipo"

, "Container Order"
: ""

, "Container, Containers"
: [
  "Contenedor"
 ,"Contenedores"

]
, "Model"
: "Modelo"

, "personal"
: "personal"

, "shared"
: "compartido"

, "Color"
: "Color"

, "Container Hierarchy/Name"
: ""

, "Note for Owner"
: "Nota para el Propietario"

, "Do you really want to delete the selected roles?"
: "¿Realmente desea borrar los cargos seleccionados?"

, "Deleting role(s)..."
: "Borrando cargo(s)..."

, "Add Role"
: ""

, "Edit Role"
: ""

, "Delete Role"
: ""

, "Displaying roles {0} - {1} of {2}"
: "Mostrando cargos {0} - {1} of {2}"

, "No roles to display"
: "Sin cargos para mostrar"

, "Do you really want to delete the selected tags?"
: "¿Realmente quieres eliminar las etiquetas seleccionadas?"

, "Deleting tag(s)..."
: "Eliminando etiqueta(s)..."

, "Add Tag"
: ""

, "Edit Tag"
: ""

, "Delete Tag"
: ""

, "Displaying tags {0} - {1} of {2}"
: "Mostrando etiquetas {0} - {1} de {2}"

, "No tags to display"
: "No hay etiquetas que mostrar"

, "Usage:&#160;"
: "Uso:&#160;"

, "Label"
: "Etiqueta"

, "Value"
: "Valor"

, "Default ({0})"
: ""

, "Yes"
: ""

, "No"
: ""

, "Customfield, Customfields"
: [
  "Campo Personalizado"
 ,"Campos Personalizados"

]
, "This custom field is still in use!"
: ""

, "Are you sure you want to delete them?"
: ""

, "Please configure store for this field type"
: "Por favor configure el almacén para este tipo de campo"

, "Record Class"
: "Clase de Registro"

, "Given record class not found"
: "La clase de registro proporcionada no fue encontrada"

, "Cancel"
: "Cancelar"

, "OK"
: "Aceptar"

, "Configure store"
: "Configurar almacenamiento"

, "Custom field definition"
: "Definición de campo personalizado"

, "Text"
: "Texto"

, "Textarea"
: ""

, "Number"
: "Número"

, "Date"
: "Fecha"

, "DateTime"
: "FechaHora"

, "Time"
: "Hora"

, "Boolean"
: "Booleano"

, "Search Combo"
: "Búsqueda de Combo"

, "Key Field"
: "Campo Llave"

, "Record"
: "Registro"

, "Record List"
: ""

, "Length"
: "Longitud"

, "Required"
: ""

, "Custom field additional properties"
: "Propiedades adicionales de campo personalizado"

, "Tab Panel"
: ""

, "Customfield already exists. Please choose another name."
: "Campo personalizado existente. Por favor escoge otro nombre."

, "Enable Account"
: ""

, "Disable Account"
: ""

, "Reset Password"
: ""

, "Reset Pin"
: ""

, "Display name"
: ""

, "Login name"
: ""

, "Last name"
: "Apellidos"

, "First name"
: "Nombres"

, "Email"
: "Email"

, "Email usage"
: ""

, "Filesystem usage"
: ""

, "OpenID"
: "OpenID"

, "Last login at"
: "Último ingreso el"

, "Last login from"
: "Último ingreso desde"

, "Password changed"
: "Contraseña cambiada"

, "Expires"
: "Expira"

, "Set new password"
: "Establecer nueva contraseña"

, "Please enter the new password:"
: "Porfavor escriba la nueva contraseña:"

, "Set new pin"
: ""

, "Please enter the new pin:"
: ""

, "Users"
: "Usuarios"

, "Samba User, Samba Users"
: [
  "Usuario de Samba"
 ,"Usuarios de Samba"

]
, "Email User, Email Users"
: [
  "Usuario de Correo"
 ,"Usuarios de Correo"

]
, "Domain is not allowed. Check your SMTP domain configuration."
: "El dominio no está permitido. Compruebe su configuración de dominios SMTP."

, "Special characters are not allowed in login name."
: ""

, "Passwords do not match!"
: "¡Las contraseñas no coinciden!"

, "Passwords match!"
: "¡Las contraseñas coinciden!"

, "Primary group"
: "Grupo primario"

, "Unix"
: "Unix"

, "Home Directory"
: "Carpeta personal"

, "Login Shell"
: "Intérprete (shell) de acceso"

, "Windows"
: "Windows"

, "Home Drive"
: "Unidad Home"

, "Logon Time"
: "Hora de Ingreso"

, "never logged in"
: "nunca ha ingresado"

, "Home Path"
: "Ubicación Home"

, "Logoff Time"
: "Hora de Salida"

, "never logged off"
: "nunca ha salido"

, "Profile Path"
: "Ubicación del Perfil"

, "Password Last Set"
: "Última Contraseña Guardada"

, "never"
: "nunca"

, "Logon Script"
: "Script de Inicio"

, "Password Can Change"
: "La Contraseña Puede Cambiar"

, "not set"
: "sin guardar"

, "Password Must Change"
: "La Contraseña Debe Cambiar"

, "Kick Off Time"
: "Tiempo de Expulsión"

, "Filesystem Quota"
: ""

, "Quota"
: "Cuota"

, "no quota set"
: "no existe cuota establecida"

, "Current Filesystem usage"
: ""

, "IMAP Quota"
: ""

, "Current Mailbox size"
: "Tamaño actual del Mailbox"

, "Sieve Quota"
: ""

, "Current Sieve size"
: "Tamaño actual del Filtro"

, "Information"
: "Información"

, "Last Login"
: "Booleano"

, "Domain not allowed"
: ""

, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
: ""

, "Email Alias"
: "Pseudónimo de Correo"

, "Add an alias address..."
: "Agregar un pseudónimo de dirección..."

, "Forwarding to self"
: ""

, "You are not allowed to set a forward email address that is identical to the users primary email or one of his aliases."
: ""

, "Email Forward"
: "Reenvío de Correo"

, "Add a forward address..."
: "Agregar una dirección de correo de reenvio..."

, "Forward Only"
: "Sólo Reenviar"

, "Password confirmation"
: "Confirmación de Contraseña"

, "Repeat password"
: "Repetir Contraseña"

, "Ok"
: "Aceptar"

, "Account"
: "Cuenta"

, "Password"
: "Contraseña"

, "expired"
: "expirado"

, "blocked"
: "bloqueado"

, "Invalid Status"
: "estado inválido"

, "Blocked status is only valid if the user tried to login with a wrong password to often. It is not possible to set this status here."
: "Estado de bloqueo sólo es válido si el usuario trata de entrar con una contraseña incorrecta a menudo. No es posible establecer este estado aquí."

, "don't know"
: "desconocido"

, "Password set"
: "Contraseña guardada"

, "User groups"
: "Grupos de usuario"

, "User roles"
: "Cargos de usuario"

, "Fileserver"
: "Servidor de Archivos"

, "Filesystem"
: ""

, "IMAP"
: "IMAP"

, "SMTP"
: "SMTP"

, "Updating Tag"
: "Actualizando Etiqueta"

, "Could not save tag ({0})"
: ""

, "Allowed Contexts"
: "Contextos Permitidos"

, "Context"
: "Contexto"

, "Account Rights"
: "Derechos de Cuenta"

, "View"
: "Ver"

, "Use"
: "Usar"

, "Tag Name"
: "Nombre de la etiqueta"

, "Tag"
: "Etiqueta"

, "Add New Tag"
: "Agregar Nueva Etiqueta"

, "Edit Tag \"{0}\""
: "Editar Etiqueta «{0}»"

, "Default IMAP user settings"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Admin Application."
: ""

, "Prevent special chars in login name"
: ""

, "Force retype of new password in user edit dialog"
: ""

, "manage access log"
: "administrar log de accesos"

, "delete access log entries"
: "borrar entradas de log de accesos"

, "manage accounts"
: "administrar cuentas"

, "add and edit users and groups, add group members, change user passwords"
: "agregar y editar usuarios y groups, agregar miembros de grupos, cambiar contraseñas de usuarios"

, "manage applications"
: "administrar aplicaciones"

, "enable and disable applications, edit application settings"
: "habilitar y deshabilitar aplicaciones, editar configuraciones de la aplicación"

, "manage roles"
: "administrar cargos"

, "add and edit roles, add new members to roles, add application rights to roles"
: "agregar y editar cargos, agregar nuevos miembros a los cargos, agregar privilegios de aplicacion a cargos"

, "manage shared tags"
: "administrar etiquetas compartidas"

, "add, delete and edit shared tags"
: "agregar, borrar y editar etiquetas compartidas"

, "manage computers"
: "administrar computadoras"

, "add, delete and edit (samba) computers"
: "agregar, borrar y editar computadoras (samba)"

, "manage containers"
: "administrar contenedores"

, "add, delete and edit containers and manage container grants"
: "agregar, eliminar y editar contenedores y administrar las asignaciones de contenedor"

, "manage customfields"
: ""

, "add and edit customfields"
: ""

, "view access log"
: "ver log de acceso"

, "view access log list"
: "ver listado de log de acceso"

, "view accounts"
: "ver cuentas"

, "view accounts list and details"
: "ver listado de cuentas y detalles"

, "view applications"
: "ver aplicaciones"

, "view applications list and details"
: "ver listado de aplicaciones y detalles"

, "view roles"
: "ver cargos"

, "view roles list and details"
: "ver lista de cargos y detalles"

, "view computers"
: "ver computadores"

, "view computers list and details"
: "ver lista de computadores y detalles"

, "view containers"
: "ver contenedores"

, "view personal and shared containers"
: "ver contenedores personales y compartidos"

, "view customfields"
: ""

, "view customfields list"
: ""

, "view serverinfo"
: ""

, "view serverinfo list"
: ""

, "view quota usage"
: ""

, "Your container has been changed"
: "Tu contenedor a sido modificado"

, "Your container has been changed by %1$s %2$sNote: %3$s"
: "Tu contenedor a sido modificado por %1$s %2$sNota: %3$s"

, "Could not save tag without (view-)rights"
: ""

, "User"
: "Usuario"

, "Access Log"
: "Log de Acceso"

, "Computer"
: "Computadora"

, "Group"
: "Grupo"

, "Application"
: "Aplicación"

, "Config"
: ""

, "Container"
: "Contenedor"

, "Customfield"
: "Campo Personalizado"

, "Samba User"
: "Usuario de Samba"

, "Email User"
: "Usuario de Correo"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2020.03.4.tar.bz2: Admin/js/Admin-lang-es_MX-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Admin **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:09+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Spanish (Mexico) (http://www.transifex.com/tine20/tine20/language/es_MX/)\nLanguage: es_MX\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Enable Application"
: ""

, "Disable Application"
: ""

, "Settings"
: ""

, "{0} Settings"
: "{0} Configuraciones"

, "Search:"
: "Buscar:"

, "Disabled"
: ""

, "Enabled"
: ""

, "Unknown status ({0})"
: ""

, "Displaying application {0} - {1} of {2}"
: "Mostrando aplicación {0} - {1} of {2}"

, "No applications to display"
: "No hay aplicaciones para mostrar"

, "Order"
: "Ordenar"

, "Name"
: "Nombre"

, "Status"
: "Estado"

, "Version"
: "Versión"

, "Confirm"
: "Confirmar"

, "Do you really want to delete the selected groups?"
: "¿Realmente desea borrar los grupos seleccionados?"

, "Deleting group(s)..."
: "Borrando grupo(s)..."

, "Failed"
: "Falló"

, "Some error occurred while trying to delete the group."
: "Ocurrió un error al intentar borrar este grupo."

, "Add Group"
: ""

, "Edit Group"
: ""

, "Delete Group"
: ""

, "Displaying groups {0} - {1} of {2}"
: "Mostrando grupos {0} - {1} of {2}"

, "No groups to display"
: "No hay grupos para mostrar"

, "ID"
: "ID"

, "E-mail"
: ""

, "Description"
: "Descripción"

, "Creation Time"
: ""

, "Created By"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Errors"
: "Errores"

, "Please configure store for this field type"
: "Por favor configure el almacén para este tipo de campo"

, "Application, Applications"
: [
  "Aplicación"
 ,"Aplicaciones"

]
, "Record Class"
: "Clase de Registro"

, "Given record class not found"
: "La clase de registro proporcionada no fue encontrada"

, "Cancel"
: "Cancelar"

, "OK"
: "Aceptar"

, "Configure store"
: "Configurar almacenamiento"

, "Model"
: "Modelo"

, "Custom field definition"
: "Definición de campo personalizado"

, "Text"
: "Texto"

, "Textarea"
: ""

, "Number"
: "Número"

, "Date"
: "Fecha"

, "DateTime"
: "FechaHora"

, "Time"
: "Hora"

, "Boolean"
: "Booleano"

, "Search Combo"
: "Búsqueda de Combo"

, "Key Field"
: "Campo Llave"

, "Record"
: "Registro"

, "Record List"
: ""

, "Type"
: "Tipo"

, "Label"
: "Etiqueta"

, "Length"
: "Longitud"

, "Required"
: ""

, "Custom field additional properties"
: "Propiedades adicionales de campo personalizado"

, "Tab Panel"
: ""

, "Group, Groups"
: [
  "Grupo"
 ,"Grupos"

]
, "Customfield already exists. Please choose another name."
: "Campo personalizado existente. Por favor escoge otro nombre."

, "Customfield, Customfields"
: [
  "Campo Personalizado"
 ,"Campos Personalizados"

]
, "This custom field is still in use!"
: ""

, "Are you sure you want to delete them?"
: ""

, "Yes"
: ""

, "No"
: ""

, "Config, Configs"
: [
  ""
 ,""

]
, "Value"
: "Valor"

, "Default ({0})"
: ""

, "Computer Name"
: "Nombre del Computador"

, "Default Addressbook for new contacts and groups"
: "Agenda predeterminada para nuevos contactos y grupos"

, "Please wait"
: "Por favor espere"

, "Updating Tag"
: "Actualizando Etiqueta"

, "Could not save tag ({0})"
: ""

, "Please fix the errors noted."
: "Por favor corrija los errores indicados."

, "Allowed Contexts"
: "Contextos Permitidos"

, "Context"
: "Contexto"

, "Account Rights"
: "Derechos de Cuenta"

, "View"
: "Ver"

, "Use"
: "Usar"

, "Tag Name"
: "Nombre de la etiqueta"

, "Color"
: "Color"

, "Transferring {0}..."
: "Transfiriendo {0}..."

, "Tag"
: "Etiqueta"

, "Add New Tag"
: "Agregar Nueva Etiqueta"

, "Edit Tag \"{0}\""
: "Editar Etiqueta «{0}»"

, "Do you really want to delete the selected tags?"
: "¿Realmente quieres eliminar las etiquetas seleccionadas?"

, "Deleting tag(s)..."
: "Eliminando etiqueta(s)..."

, "Add Tag"
: ""

, "Edit Tag"
: ""

, "Delete Tag"
: ""

, "Displaying tags {0} - {1} of {2}"
: "Mostrando etiquetas {0} - {1} de {2}"

, "No tags to display"
: "No hay etiquetas que mostrar"

, "Usage:&#160;"
: "Uso:&#160;"

, "Updating Memberships"
: "Actualizando Membresias"

, "Could not save role."
: "No se pudo guardar cargo."

, "Deleting role..."
: "Borrando cargo..."

, "Some error occurred while trying to delete the role."
: "Ocurrió un error al intentar borrar el cargo."

, "Rights"
: "Derechos"

, "Members"
: "Miembros"

, "Role Name"
: "Nombre del Cargo"

, "Role"
: "Cargo"

, "Add New Role"
: "Agregar Nuevo Cargo"

, "Edit Role \"{0}\""
: "Editar Cargo \"{0}\""

, "Do you really want to delete the selected roles?"
: "¿Realmente desea borrar los cargos seleccionados?"

, "Deleting role(s)..."
: "Borrando cargo(s)..."

, "Add Role"
: ""

, "Edit Role"
: ""

, "Delete Role"
: ""

, "Displaying roles {0} - {1} of {2}"
: "Mostrando cargos {0} - {1} of {2}"

, "No roles to display"
: "Sin cargos para mostrar"

, "Access Log, Access Logs"
: [
  "Log de Acceso"
 ,"Logs de Acceso"

]
, "Groups"
: "Grupos"

, "Applications"
: "Aplicaciones"

, "Configs"
: ""

, "Domain is not allowed. Check your SMTP domain configuration."
: "El dominio no está permitido. Compruebe su configuración de dominios SMTP."

, "Special characters are not allowed in login name."
: ""

, "Passwords do not match!"
: "¡Las contraseñas no coinciden!"

, "Passwords match!"
: "¡Las contraseñas coinciden!"

, "Primary group"
: "Grupo primario"

, "Unix"
: "Unix"

, "Home Directory"
: "Carpeta personal"

, "Login Shell"
: "Intérprete (shell) de acceso"

, "Windows"
: "Windows"

, "Home Drive"
: "Unidad Home"

, "Login Time"
: "Hora de Ingreso"

, "never logged in"
: "nunca ha ingresado"

, "Home Path"
: "Ubicación Home"

, "Logout Time"
: "Hora de Salida"

, "never logged off"
: "nunca ha salido"

, "Profile Path"
: "Ubicación del Perfil"

, "Password Last Set"
: "Última Contraseña Guardada"

, "never"
: "nunca"

, "Logon Script"
: "Script de Inicio"

, "Password Can Change"
: "La Contraseña Puede Cambiar"

, "not set"
: "sin guardar"

, "Password Must Change"
: "La Contraseña Debe Cambiar"

, "Kick Off Time"
: "Tiempo de Expulsión"

, "Filesystem Quota"
: ""

, "Quota"
: "Cuota"

, "no quota set"
: "no existe cuota establecida"

, "Current Filesystem usage"
: ""

, "IMAP Quota"
: ""

, "Current Mailbox size"
: "Tamaño actual del Mailbox"

, "Sieve Quota"
: ""

, "Current Sieve size"
: "Tamaño actual del Filtro"

, "Information"
: "Información"

, "Last Login"
: "Booleano"

, "Domain not allowed"
: ""

, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
: ""

, "E-mail Alias"
: ""

, "Add an alias address..."
: "Agregar un pseudónimo de dirección..."

, "This alias can be used for sending e-mails."
: ""

, "Forwarding to self"
: ""

, "You are not allowed to set a forwarding e-mail address that is identical to the users primary e-mail or one of his aliases."
: ""

, "E-mail Forward"
: ""

, "Add a forwarding address..."
: ""

, "Forward Only"
: "Sólo Reenviar"

, "Password confirmation"
: "Confirmación de Contraseña"

, "Repeat password"
: "Repetir Contraseña"

, "Ok"
: "Aceptar"

, "Account"
: "Cuenta"

, "First name"
: "Nombres"

, "Last name"
: "Apellidos"

, "Login name"
: ""

, "Password"
: "Contraseña"

, "OpenID"
: "OpenID"

, "enabled"
: "habilitado"

, "disabled"
: "deshabilitado"

, "expired"
: "expirado"

, "blocked"
: "bloqueado"

, "Invalid Status"
: "estado inválido"

, "Blocked status is only valid if the user tried to login with a wrong password to often. It is not possible to set this status here."
: "Estado de bloqueo sólo es válido si el usuario trata de entrar con una contraseña incorrecta a menudo. No es posible establecer este estado aquí."

, "Expires"
: "Expira"

, "Visibility"
: "Visibilidad"

, "Display in addressbook"
: "Mostrar en libreta de direcciones"

, "Hide from addressbook"
: "Esconder de la libreta de direcciones"

, "Saved in Addressbook"
: "Guardado en libreta de direcciones"

, "Last login at"
: "Último ingreso el"

, "don't know"
: "desconocido"

, "Last login from"
: "Último ingreso desde"

, "Password set"
: "Contraseña guardada"

, "User groups"
: "Grupos de usuario"

, "User roles"
: "Cargos de usuario"

, "Fileserver"
: "Servidor de Archivos"

, "Filesystem"
: ""

, "IMAP"
: "IMAP"

, "SMTP"
: "SMTP"

, "User, Users"
: [
  "Usuario"
 ,"Usuarios"

]
, "Users"
: "Usuarios"

, "Samba User, Samba Users"
: [
  "Usuario de Samba"
 ,"Usuarios de Samba"

]
, "Email User, Email Users"
: [
  "Usuario de Correo"
 ,"Usuarios de Correo"

]
, "Enable Account"
: ""

, "Disable Account"
: ""

, "Reset Password"
: ""

, "Reset Pin"
: ""

, "Display name"
: ""

, "E-mail usage"
: ""

, "Filesystem usage"
: ""

, "Password changed"
: "Contraseña cambiada"

, "Set new password"
: "Establecer nueva contraseña"

, "Please enter the new password:"
: "Porfavor escriba la nueva contraseña:"

, "Set new pin"
: ""

, "Please enter the new pin:"
: ""

, "Group Name"
: "Nombre del Grupo"

, "Only system accounts can be added to Addressbook group"
: ""

, "Group Members"
: "Miembros del Grupo"

, "personal"
: "personal"

, "shared"
: "compartido"

, "Container Hierarchy/Name"
: ""

, "Note for Owner"
: "Nota para el Propietario"

, "Info"
: ""

, "Please create Resources in Addressbook or CoreData."
: ""

, "Container, Containers"
: [
  "Contenedor"
 ,"Contenedores"

]
, "Container Name"
: "Nombre del Contenedor"

, "Container Order"
: ""

, "Computer, Computers"
: [
  "Computadora"
 ,"Computadoras"

]
, "Size"
: ""

, "Revision Size"
: ""

, "Total size of all available revisions"
: ""

, "Quota Usage"
: ""

, "Roles"
: "Cargos"

, "Containers"
: "Contenedores"

, "Shared Tags"
: "Etiquetas Compartidas"

, "Customfields"
: "Campos Personalizados"

, "Computers"
: "Computadoras"

, "Server Information"
: ""

, "ActiveSync Devices"
: ""

, "E-mail Accounts"
: ""

, "Admin"
: "Admin"

, "Refresh"
: ""

, "Feature is disabled by configuration."
: ""

, "IP Address"
: "Dirección IP"

, "Client Type"
: "Tipo de Cliente"

, "Session ID"
: "ID de Sesión"

, "Login Name"
: "Nombre de Usuario"

, "Result"
: "Resultado"

, "user blocked"
: "usuario bloqueado"

, "password expired"
: "contraseña caducada"

, "user disabled"
: "usuario deshabilitado"

, "invalid password"
: "contraseña incorrecta"

, "ambiguous username"
: "nombre de usuario ambiguo"

, "user not found"
: "usuario no encontrado"

, "failure"
: "falla"

, "success"
: "exitoso"

, "Default IMAP user settings"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Admin Application."
: ""

, "Prevent special chars in login name"
: ""

, "Force retype of new password in user edit dialog"
: ""

, "Your container has been changed"
: "Tu contenedor a sido modificado"

, "Your container has been changed by %1$s %2$sNote: %3$s"
: "Tu contenedor a sido modificado por %1$s %2$sNota: %3$s"

, "Manage access log"
: ""

, "Delete access log entries."
: ""

, "Manage accounts"
: ""

, "Add and edit users and groups, add group members, change user passwords."
: ""

, "Manage e-mail accounts"
: ""

, "Add and edit shared and personal e-mail accounts."
: ""

, "Manage applications"
: ""

, "Enable and disable applications, edit application settings."
: ""

, "Manage roles"
: ""

, "Add and edit roles, add new members to roles, add application rights to roles."
: ""

, "Manage shared tags"
: ""

, "Add, delete and edit shared tags."
: ""

, "Manage computers"
: ""

, "Add, delete and edit (samba) computers."
: ""

, "Manage containers"
: ""

, "Add, delete and edit containers and manage container grants."
: ""

, "Manage customfields"
: ""

, "Add and edit customfields."
: ""

, "View access log"
: ""

, "View access log list."
: ""

, "View accounts"
: ""

, "View accounts list and details."
: ""

, "View e-mail accounts"
: ""

, "View shared and personal e-mail accounts."
: ""

, "View applications"
: ""

, "View applications list and details."
: ""

, "View roles"
: ""

, "View roles list and details."
: ""

, "View shared tags"
: ""

, "View shared tags list and details."
: ""

, "View computers"
: ""

, "View computers list and details."
: ""

, "View containers"
: ""

, "View personal and shared containers."
: ""

, "View customfields"
: ""

, "View customfields list."
: ""

, "View serverinfo"
: ""

, "View serverinfo list."
: ""

, "View quota usage"
: ""

, "View quota usage."
: ""








































, "Application"
: "Aplicación"

, "Group"
: "Grupo"

, "Customfield"
: "Campo Personalizado"

, "Config"
: ""

, "Access Log"
: "Log de Acceso"

, "User"
: "Usuario"

, "Samba User"
: "Usuario de Samba"

, "Email User"
: "Usuario de Correo"

, "Container"
: "Contenedor"

, "Computer"
: "Computadora"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
